@@ -24,7 +24,7 @@ class BalconyServiceSummarizer(BaseBalconyApp,
     def get_cli_app(self, *args, **kwargs) -> typer.main.Typer:
         app = typer.Typer(no_args_is_help=True)
         
-        @app.callback()
+        @app.callback(invoke_without_command=True)
         def _command(
             service: Optional[str] = typer.Argument(None, show_default=False,help='AWS Service Name'),
         ):
